==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appconfiguration/kotlin/Replica.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appconfiguration.kotlin

import com.pulumi.azurenative.appconfiguration.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.appconfiguration.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [Replica].
 */
@PulumiTagMarker
public class ReplicaResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ReplicaArgs = ReplicaArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ReplicaArgsBuilder.() -> Unit) {
        val builder = ReplicaArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): Replica {
        val builtJavaResource = com.pulumi.azurenative.appconfiguration.Replica(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return Replica(builtJavaResource)
    }
}

/**
 * The replica resource.
 * Azure REST API version: 2023-03-01.
 * Other available API versions: 2023-08-01-preview, 2023-09-01-preview.
 * ## Example Usage
 * ### Replicas_Create
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var replica = new AzureNative.AppConfiguration.Replica("replica", new()
 *     {
 *         ConfigStoreName = "contoso",
 *         Location = "eastus",
 *         ReplicaName = "myReplicaEus",
 *         ResourceGroupName = "myResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/appconfiguration/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := appconfiguration.NewReplica(ctx, "replica", &appconfiguration.ReplicaArgs{
 * 			ConfigStoreName:   pulumi.String("contoso"),
 * 			Location:          pulumi.String("eastus"),
 * 			ReplicaName:       pulumi.String("myReplicaEus"),
 * 			ResourceGroupName: pulumi.String("myResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.appconfiguration.Replica;
 * import com.pulumi.azurenative.appconfiguration.ReplicaArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var replica = new Replica("replica", ReplicaArgs.builder()
 *             .configStoreName("contoso")
 *             .location("eastus")
 *             .replicaName("myReplicaEus")
 *             .resourceGroupName("myResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:appconfiguration:Replica myReplicaEus /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppConfiguration/configurationStores/{configStoreName}/replicas/{replicaName}
 * ```
 */
public class Replica internal constructor(
    override val javaResource: com.pulumi.azurenative.appconfiguration.Replica,
) : KotlinCustomResource(javaResource, ReplicaMapper) {
    /**
     * The URI of the replica where the replica API will be available.
     */
    public val endpoint: Output<String>
        get() = javaResource.endpoint().applyValue({ args0 -> args0 })

    /**
     * The location of the replica.
     */
    public val location: Output<String>?
        get() = javaResource.location().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The name of the replica.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The provisioning state of the replica.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Resource system metadata.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ReplicaMapper : ResourceMapper<Replica> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.appconfiguration.Replica::class == javaResource::class

    override fun map(javaResource: Resource): Replica = Replica(
        javaResource as
            com.pulumi.azurenative.appconfiguration.Replica,
    )
}

/**
 * @see [Replica].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [Replica].
 */
public suspend fun replica(name: String, block: suspend ReplicaResourceBuilder.() -> Unit):
    Replica {
    val builder = ReplicaResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [Replica].
 * @param name The _unique_ name of the resulting resource.
 */
public fun replica(name: String): Replica {
    val builder = ReplicaResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/appconfiguration/kotlin/Replica.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appconfiguration.kotlin

import com.pulumi.azurenative.appconfiguration.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.appconfiguration.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [Replica].
 */
@PulumiTagMarker
public class ReplicaResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ReplicaArgs = ReplicaArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ReplicaArgsBuilder.() -> Unit) {
        val builder = ReplicaArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): Replica {
        val builtJavaResource = com.pulumi.azurenative.appconfiguration.Replica(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return Replica(builtJavaResource)
    }
}

/**
 * The replica resource.
 * Azure REST API version: 2023-03-01.
 * Other available API versions: 2023-08-01-preview, 2023-09-01-preview.
 * ## Example Usage
 * ### Replicas_Create
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var replica = new AzureNative.AppConfiguration.Replica("replica", new()
 *     {
 *         ConfigStoreName = "contoso",
 *         Location = "eastus",
 *         ReplicaName = "myReplicaEus",
 *         ResourceGroupName = "myResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/appconfiguration/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := appconfiguration.NewReplica(ctx, "replica", &appconfiguration.ReplicaArgs{
 * 			ConfigStoreName:   pulumi.String("contoso"),
 * 			Location:          pulumi.String("eastus"),
 * 			ReplicaName:       pulumi.String("myReplicaEus"),
 * 			ResourceGroupName: pulumi.String("myResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.appconfiguration.Replica;
 * import com.pulumi.azurenative.appconfiguration.ReplicaArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var replica = new Replica("replica", ReplicaArgs.builder()
 *             .configStoreName("contoso")
 *             .location("eastus")
 *             .replicaName("myReplicaEus")
 *             .resourceGroupName("myResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:appconfiguration:Replica myReplicaEus /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppConfiguration/configurationStores/{configStoreName}/replicas/{replicaName}
 * ```
 */
public class Replica internal constructor(
    override val javaResource: com.pulumi.azurenative.appconfiguration.Replica,
) : KotlinCustomResource(javaResource, ReplicaMapper) {
    /**
     * The URI of the replica where the replica API will be available.
     */
    public val endpoint: Output<String>
        get() = javaResource.endpoint().applyValue({ args0 -> args0 })

    /**
     * The location of the replica.
     */
    public val location: Output<String>?
        get() = javaResource.location().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The name of the replica.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The provisioning state of the replica.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Resource system metadata.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ReplicaMapper : ResourceMapper<Replica> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.appconfiguration.Replica::class == javaResource::class

    override fun map(javaResource: Resource): Replica = Replica(
        javaResource as
            com.pulumi.azurenative.appconfiguration.Replica,
    )
}

/**
 * @see [Replica].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [Replica].
 */
public suspend fun replica(name: String, block: suspend ReplicaResourceBuilder.() -> Unit): Replica {
    val builder = ReplicaResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [Replica].
 * @param name The _unique_ name of the resulting resource.
 */
public fun replica(name: String): Replica {
    val builder = ReplicaResourceBuilder()
    builder.name(name)
    return builder.build()
}
